package com.vendor.loader.ui;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.vendor.loader.Messages;
import com.vendor.loader.struct.UpgradeInfo;
import com.vendor.loader.ui.LabelTextField;
import com.vendor.loader.util.IniFileParser;
import com.vendor.loader.util.StringUtil;
import com.vendor.loader.views.LoaderView;
import java.math.BigInteger;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;

public class UpgradeInfoGroup {
  private LabelTextField downloadPid;
  
  private LabelTextField tableId;
  
  private LabelTextField manufacturerId;
  
  private LabelTextField hardwareId;
  
  private LabelTextField softwareId;
  
  private LabelTextField startSn;
  
  private LabelTextField endSn;
  
  private UpgradeInfo input;
  
  private static final String manufacturerIdMin = "0x0000";
  
  private static final String manufacturerIdMax = "0xFFFF";
  
  private static final String hardwareIdMin = "0x00000000";
  
  private static final String hardwareIdMax = "0xFFFFFFFF";
  
  private static final int labelWidth = 240;
  
  public UpgradeInfoGroup(Composite parent) {
    createControls(parent);
  }
  
  private void createControls(Composite group) {
    this.downloadPid = new LabelTextField(group, Messages.UpgradeInfoGroup_1, 240, null, "0x1b58", "0x20~0x1FFE");
    this.tableId = new LabelTextField(group, Messages.UpgradeInfoGroup_3, 240, null, "0xdd", "0x40~0xFF");
    if (LoaderView.isChipBranchSeries0()) {
      this.downloadPid.hide();
      this.tableId.hide();
    } 
    this.manufacturerId = new LabelTextField(group, Messages.UpgradeInfoGroup_5, 240, null, "0x0003", "0x0000~0xFFFF");
    this.hardwareId = new LabelTextField(group, Messages.UpgradeInfoGroup_7, 240, null, "0x00000001", "0x00000000~0xFFFFFFFF");
    this.softwareId = new LabelTextField(group, Messages.UpgradeInfoGroup_9, 240, null, "0x01010101", "0x00000000~0xFFFFFFFF");
    this.startSn = new LabelTextField(group, Messages.UpgradeInfoGroup_Start_Sn, 240, null, "0x00000000", "0x00000000~0xFFFFFFFF");
    this.endSn = new LabelTextField(group, Messages.UpgradeInfoGroup_End_Sn, 240, null, "0xffffffff", "0x00000000~0xFFFFFFFF");
  }
  
  public void setInput(IniFileParser parse, UpgradeInfo info) {
    this.input = info;
    if (parse.getDownloadPid() != null)
      this.downloadPid.getTextControl().setText(parse.getDownloadPid()); 
    if (parse.getDownloadTableId() != null)
      this.tableId.getTextControl().setText(parse.getDownloadTableId()); 
    if (parse.getManufacturerId() != null)
      this.manufacturerId.getTextControl().setText(parse.getManufacturerId()); 
    if (parse.getHardwareVersion() != null)
      this.hardwareId.getTextControl().setText(parse.getHardwareVersion()); 
    if (parse.getSoftwareVersion() != null)
      this.softwareId.getTextControl().setText(parse.getSoftwareVersion()); 
    if (parse.getStartSn() != null)
      this.startSn.getTextControl().setText(parse.getStartSn()); 
    if (parse.getEndSn() != null)
      this.endSn.getTextControl().setText(parse.getEndSn()); 
  }
  
  public UpgradeInfo getInput() {
    if (this.input == null)
      this.input = new UpgradeInfo(); 
    this.input.setDownloadPid((int)StringUtil.convertString(getDownloadPid()));
    this.input.setDownloadTableId(
        (int)StringUtil.convertString(getDownloadTableId()));
    this.input.setManufacturerId(
        (int)StringUtil.convertString(getManufacturerId()));
    this.input.setHardwareVersion(
        (int)StringUtil.convertString(getHardwareVersion()));
    this.input.setSoftwareVersion(
        (int)StringUtil.convertString(getSoftwareVersion()));
    this.input.setStartSn((int)StringUtil.convertString(getStartSn()));
    this.input.setEndSn((int)StringUtil.convertString(getEndSn()));
    return this.input;
  }
  
  public boolean validateInput() {
    try {
      if (!StringUtil.hexInRange(this.downloadPid.getText(), "0x20", "0x1FFE")) {
        showError(Messages.UpgradeInfoGroup_23);
        return false;
      } 
      if (!StringUtil.hexInRange(this.tableId.getText(), "0x40", "0xFF")) {
        showError(Messages.UpgradeInfoGroup_26);
        return false;
      } 
      if (!StringUtil.hexInRange(this.manufacturerId.getText(), "0x0000", "0xFFFF")) {
        showError(NLS.bind(Messages.UpgradeInfoGroup_29, new Object[] { "0x0000", "0xFFFF" }));
        return false;
      } 
      if (!StringUtil.hexInRange(this.hardwareId.getText(), "0x00000000", "0xFFFFFFFF")) {
        showError(NLS.bind(Messages.UpgradeInfoGroup_32, new Object[] { "0x00000000", "0xFFFFFFFF" }));
        return false;
      } 
      if (!StringUtil.hexInRange(this.softwareId.getText(), "0x00000000", "0xFFFFFFFF")) {
        showError(NLS.bind(Messages.UpgradeInfoGroup_35, new Object[] { "0x00000000", "0xFFFFFFFF" }));
        return false;
      } 
      if (!StringUtil.hexInRange(this.startSn.getText(), "0x00000000", "0xFFFFFFFF")) {
        showError(NLS.bind(Messages.UpgradeInfoGroup_StartSnInputError, new Object[] { "0x00000000", "0xFFFFFFFF" }));
        return false;
      } 
      if (!StringUtil.hexInRange(this.endSn.getText(), "0x00000000", "0xFFFFFFFF")) {
        showError(NLS.bind(Messages.UpgradeInfoGroup_EndSnInputError, new Object[] { "0x00000000", "0xFFFFFFFF" }));
        return false;
      } 
      BigInteger sn = StringUtil.toBigInteger(this.startSn.getText());
      BigInteger en = StringUtil.toBigInteger(this.endSn.getText());
      if (sn.compareTo(en) >= 0) {
        showError(Messages.UpgradeInfoGroup_StartSnAndEndSnInputError);
        return false;
      } 
    } catch (NumberFormatException e) {
      showError(Messages.UpgradeInfoGroup_InputInvalid);
      return false;
    } 
    return true;
  }
  
  private void showError(String message) {
    MessageDialog.openError(Display.getDefault().getActiveShell(), Messages.UpgradeInfoGroup_36, message);
  }
  
  public boolean hasInputText() {
    if (!this.downloadPid.hasInputText(Messages.UpgradeInfoGroup_2) || 
      !this.tableId.hasInputText(Messages.UpgradeInfoGroup_4) || 
      !this.manufacturerId.hasInputText(Messages.UpgradeInfoGroup_13) || 
      !this.hardwareId.hasInputText(Messages.UpgradeInfoGroup_14) || 
      !this.softwareId.hasInputText(Messages.UpgradeInfoGroup_15) || 
      
      !this.startSn.hasInputText(Messages.UpgradeInfoGroup_start_sn_isEmpty) || 
      
      !this.endSn.hasInputText(Messages.UpgradeInfoGroup_end_sn_isEmpty))
      return false; 
    return true;
  }
  
  public String getDownloadPid() {
    return this.downloadPid.getText();
  }
  
  public String getDownloadTableId() {
    return this.tableId.getText();
  }
  
  public String getManufacturerId() {
    return this.manufacturerId.getText();
  }
  
  public String getSoftwareVersion() {
    return this.softwareId.getText();
  }
  
  public String getHardwareVersion() {
    return this.hardwareId.getText();
  }
  
  public String getStartSn() {
    return this.startSn.getText();
  }
  
  public String getEndSn() {
    return this.endSn.getText();
  }
}
